@@ -42,6 +42,13 @@ def remove_hashtag(text):
 def remove_url(text):
     return re.sub(r'http\S+', '', text)
 
-def remove_slang(text):
-    slang_words = slang_list.slang_words
+def remove_slang(text, slang=None, add=None):
+    if slang:
+        slang_words = slang
+    else:
+        slang_words = slang_list.slang_words.copy()
+    
+    if add:
+        slang_words.update(add)
     return ' '.join([(slang_words[t] if t in slang_words.keys() else t) for t in text.split()])
+
